@@ -24,7 +24,7 @@ APP_THEME = ["semantic-ui"]
 # See https://invenio-theme.readthedocs.io/en/latest/configuration.html
 
 # Name displayed in tab
-THEME_SITENAME = "TU Wien Research Data"
+THEME_SITENAME = "TU Data Repository"
 
 # Frontpage
 THEME_FRONTPAGE = True
